var classMeshVertexBase__3 =
[
    [ "FT", "classMeshVertexBase__3.html#ad0e4036ea609a9551899278d0487df8e", null ],
    [ "Index", "classMeshVertexBase__3.html#ada1fae2eb2df88340d0bba8a55259660", null ],
    [ "erase_counter", "classMeshVertexBase__3.html#ad055e6af4f3156284d7cdbaf9b7b7537", null ],
    [ "in_dimension", "classMeshVertexBase__3.html#a5c4fa12df2d69be97747830b823e19b7", null ],
    [ "increment_erase_counter", "classMeshVertexBase__3.html#a585bdb0eafea242296d7c4401e348372", null ],
    [ "index", "classMeshVertexBase__3.html#abebd1b0f3f700fe57a704928ace7defa", null ],
    [ "is_special", "classMeshVertexBase__3.html#acf93d7be2b44bd02fa14f1c25c5a9fe4", null ],
    [ "set_dimension", "classMeshVertexBase__3.html#a9fe48efb87f7ee8fe294f2053be1eb26", null ],
    [ "set_erase_counter", "classMeshVertexBase__3.html#a8b614f58cca0341bf2fdb9e4d6fdcbdc", null ],
    [ "set_index", "classMeshVertexBase__3.html#a3604c8c08cbb9d0b1f02dc53901fbd63", null ],
    [ "set_special", "classMeshVertexBase__3.html#a6148b21c4599c439b85e16405a1f6ad8", null ]
];